@@ -122,6 +122,12 @@ MainWindow::MainWindow(QWidget * parent) : QWidget(parent), ui(new Ui::MainWindo
   connect(searchAction, SIGNAL(triggered(bool)), ui->searchField, SLOT(setFocus()));
   addAction(searchAction);
 
+  searchAction = new QAction(this);
+  searchAction->setShortcut(QKeySequence("/"));
+  searchAction->setShortcutContext(Qt::ApplicationShortcut);
+  connect(searchAction, SIGNAL(triggered(bool)), ui->searchField, SLOT(setFocus()));
+  addAction(searchAction);
+
   ui->splitter->setHandleWidth(6);
   ui->verticalSplitter->setHandleWidth(6);
   ui->verticalSplitter->setStretchFactor(0, 5);
@@ -224,12 +230,15 @@ void MainWindow::setDarkTheme()
 
   const QString css = "QTreeView { background: #505050; }"
                       "QLineEdit { background: #505050; }"
+                      "QMenu { background: #505050; border: 1px solid rgb(100,100,100); }"
+                      "QMenu::item:selected { background: rgb(110,110,110); }"
                       "QTextEdit { background: #505050; }"
                       "QSpinBox  { background: #505050; }"
                       "QDoubleSpinBox { background: #505050; }"
                       "QToolButton:checked { background: #383838; }"
                       "QToolButton:pressed { background: #383838; }"
                       "QComboBox QAbstractItemView { background: #505050; } "
+                      "QGroupBox { border: 1px solid #808080; margin-top: 4ex; } "
                       "QFileDialog QAbstractItemView { background: #505050; } "
                       "QComboBox:editable { background: #505050; } "
                       "QProgressBar { background: #505050; }";
@@ -311,7 +320,7 @@ void MainWindow::onStartupFiltersUpdateFinished(int status)
     showUpdateErrors();
   } else if (status == Updater::UpdateSuccessful) {
     if (Updater::getInstance()->someNetworkUpdateAchieved()) {
-      showMessage(tr("Filter definitions have been updated"), 4000);
+      showMessage(tr("Filter definitions have been updated."), 4000);
     }
   } else if (status == Updater::UpdateNotNecessary) {
   }
@@ -401,11 +410,11 @@ void MainWindow::onFilterSelectionChanged()
 
 void MainWindow::onEscapeKeyPressed()
 {
+  ui->searchField->clear();
   if (_processor.isProcessing()) {
     if (_processor.isProcessingFullImage()) {
       ui->progressInfoWidget->onCancelClicked();
     } else {
-      ui->searchField->clear();
       _processor.cancel();
       ui->previewWidget->displayOriginalImage();
     }
@@ -481,11 +490,11 @@ void MainWindow::makeConnections()
   connect(ui->tbZoomReset, SIGNAL(clicked(bool)), this, SLOT(onPreviewZoomReset()));
 
   connect(ui->tbAddFave, SIGNAL(clicked(bool)), this, SLOT(onAddFave()));
+  connect(_filtersPresenter, SIGNAL(faveAdditionRequested(QString)), this, SLOT(onAddFave()));
   connect(ui->tbRemoveFave, SIGNAL(clicked(bool)), this, SLOT(onRemoveFave()));
   connect(ui->tbRenameFave, SIGNAL(clicked(bool)), this, SLOT(onRenameFave()));
 
   connect(ui->inOutSelector, SIGNAL(inputModeChanged(GmicQt::InputMode)), this, SLOT(onInputModeChanged(GmicQt::InputMode)));
-  connect(ui->inOutSelector, SIGNAL(outputMessageModeChanged(GmicQt::OutputMessageMode)), this, SLOT(onOutputMessageModeChanged(GmicQt::OutputMessageMode)));
   connect(ui->inOutSelector, SIGNAL(previewModeChanged(GmicQt::PreviewMode)), ui->previewWidget, SLOT(sendUpdateRequest()));
 
   connect(ui->cbPreview, SIGNAL(toggled(bool)), this, SLOT(onPreviewCheckBoxToggled(bool)));
@@ -522,6 +531,7 @@ void MainWindow::onPreviewUpdateRequested()
   GmicProcessor::FilterContext::VisibleRect & rect = context.visibleRect;
   ui->previewWidget->normalizedVisibleRect(rect.x, rect.y, rect.w, rect.h);
   context.inputOutputState = ui->inOutSelector->state();
+  context.outputMessageMode = DialogSettings::outputMessageMode();
   ui->previewWidget->getPositionStringCorrection(context.positionStringCorrection.xFactor, context.positionStringCorrection.yFactor);
   context.zoomFactor = ui->previewWidget->currentZoomFactor();
   context.previewWidth = ui->previewWidget->width();
@@ -577,6 +587,7 @@ void MainWindow::processImage()
   GmicProcessor::FilterContext::VisibleRect & rect = context.visibleRect;
   rect.x = rect.y = rect.w = rect.h = -1;
   context.inputOutputState = ui->inOutSelector->state();
+  context.outputMessageMode = DialogSettings::outputMessageMode();
   context.filterName = currentFilter.plainTextName;
   context.filterCommand = currentFilter.command;
   ui->filterParams->updateValueString(false); // Required to get up-to-date values of text parameters
@@ -697,11 +708,11 @@ void MainWindow::onProgressionWidgetCancelClicked()
 
 void MainWindow::onReset()
 {
-  if (_filtersPresenter->currentFilter().hash.isEmpty() && _filtersPresenter->currentFilter().isAFave) {
+  if (!_filtersPresenter->currentFilter().hash.isEmpty() && _filtersPresenter->currentFilter().isAFave) {
     ui->filterParams->setValues(_filtersPresenter->currentFilter().defaultParameterValues, true);
     return;
   }
-  if (not _filtersPresenter->currentFilter().isNoFilter()) {
+  if (!_filtersPresenter->currentFilter().isNoFilter()) {
     ui->filterParams->reset(true);
   }
 }
@@ -934,10 +945,9 @@ void MainWindow::activateFilter(bool resetZoom)
     ui->inOutSelector->show();
     ui->inOutSelector->setState(ParametersCache::getInputOutputState(filter.hash), false);
     ui->previewWidget->updateFullImageSizeIfDifferent(LayersExtentProxy::getExtent(ui->inOutSelector->inputMode()));
-    Logger::setMode(ui->inOutSelector->outputMessageMode());
+    Logger::setMode(DialogSettings::outputMessageMode());
     ui->filterName->setVisible(true);
     ui->tbAddFave->setEnabled(true);
-    // SHOW(filter.previewFactorString());
     ui->previewWidget->setPreviewFactor(filter.previewFactor, resetZoom);
     showZoomWarningIfNeeded();
     _okButtonShouldApply = true;
@@ -977,11 +987,10 @@ void MainWindow::showEvent(QShowEvent * event)
     Logger::clear();
   }
   QObject::connect(Updater::getInstance(), SIGNAL(updateIsDone(int)), this, SLOT(onStartupFiltersUpdateFinished(int)));
+  Updater::setOutputMessageMode(DialogSettings::outputMessageMode());
   int ageLimit;
   {
     QSettings settings;
-    GmicQt::OutputMessageMode mode = static_cast<GmicQt::OutputMessageMode>(settings.value("OutputMessageModeValue", GmicQt::Quiet).toInt());
-    Updater::setOutputMessageMode(mode);
     ageLimit = settings.value(INTERNET_UPDATE_PERIODICITY_KEY, INTERNET_DEFAULT_PERIODICITY).toInt();
   }
   const bool useNetwork = (ageLimit != INTERNET_NEVER_UPDATE_PERIODICITY);
@@ -1038,12 +1047,6 @@ void MainWindow::onRenameFave()
   _filtersPresenter->editSelectedFaveName();
 }
 
-void MainWindow::onOutputMessageModeChanged(GmicQt::OutputMessageMode mode)
-{
-  Logger::setMode(mode);
-  ui->previewWidget->sendUpdateRequest();
-}
-
 void MainWindow::onToggleFullScreen(bool on)
 {
   if (on && !(windowState() & Qt::WindowMaximized)) {
@@ -1088,10 +1091,20 @@ void MainWindow::onSettingsClicked()
     }
     ui->splitter->setSizes(splitterSizes);
   }
+  bool shouldUpdatePreview = false;
   if (DialogSettings::logosAreVisible()) {
-    ui->logosLabel->show();
+    if (!ui->logosLabel->isVisible()) {
+      shouldUpdatePreview = true;
+      ui->logosLabel->show();
+    }
   } else {
-    ui->logosLabel->hide();
+    if (ui->logosLabel->isVisible()) {
+      shouldUpdatePreview = true;
+      ui->logosLabel->hide();
+    }
+  }
+  if (shouldUpdatePreview) {
+    ui->previewWidget->sendUpdateRequest();
   }
 }
 
